"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_1 = require("lodash");
const utils_1 = require("./utils");
const html_minifier_terser_1 = require("html-minifier-terser");
// import debug from 'debug';
// const log = debug('vite:html');
const defaultMinifyOptions = {
    minifyCSS: true,
    minifyJS: true,
    minifyURLs: true,
    removeAttributeQuotes: true,
    trimCustomFragments: true,
    collapseWhitespace: true,
};
exports.default = (opt = {}) => {
    let viteConfig;
    return [
        {
            name: 'vite:html-pre',
            configResolved(config) {
                viteConfig = config;
            },
            transformIndexHtml: {
                enforce: 'pre',
                transform: async (html) => {
                    const { options = {} } = opt;
                    let compiledHtml = html;
                    try {
                        // Compile using lodash template syntax
                        // Expose options to the viteHtmlPluginOptions object
                        const compiled = lodash_1.template(compiledHtml);
                        compiledHtml = compiled({
                            viteHtmlPluginOptions: options,
                        });
                    }
                    catch (error) {
                        console.error('Template  compiled fail\n' + error);
                    }
                    return compiledHtml;
                },
            },
        },
        {
            name: 'vite:html-post',
            configResolved(config) {
                viteConfig = config;
            },
            transformIndexHtml: {
                enforce: 'post',
                transform: async (html) => {
                    let compiledHtml = html;
                    const { title = '', minify = viteConfig?.command === 'build', tags = [] } = opt;
                    try {
                        let processCode = utils_1.injectTitle(compiledHtml, title);
                        if (!minify) {
                            return {
                                html: processCode,
                                tags,
                            };
                        }
                        // minify code
                        if (lodash_1.isBoolean(minify)) {
                            return {
                                html: html_minifier_terser_1.minify(processCode, defaultMinifyOptions),
                                tags,
                            };
                        }
                        return {
                            html: html_minifier_terser_1.minify(processCode, {
                                ...defaultMinifyOptions,
                                ...minify,
                            }),
                            tags,
                        };
                    }
                    catch (error) {
                        console.error('Template transform fail\n' + error);
                        return { html: compiledHtml, tags };
                    }
                },
            },
        },
    ];
};
__exportStar(require("./types"), exports);
